##############################
### An introduction to `R` ###
##############################
install.packages("foreign")
require(foreign)

# Getting Help with `R`
?sum
help(sum)

# Calculating 3+4
3 + 4

# Printing 'Hello!'
print('Hello!')

# Sum 1,2 and 3
sum(1,2,3)

# Absolute value of 2 and -2
abs(2); abs(-2)

# Assign the value 42 to x
x <- 42

# Print out the value of the object x
x

# Add 2 to x
x + 2

# Add 5 to x 
x + 5

# Add 5 to x and reassigning to x
y <- x + 5

# Print out the value of the object x
y

# Storing 5 values in a vector and assigning to 'a'
a <- c(1, 2, 3, 4, 5)

# Storing 5 values in a vector and assigning to 'b'
b <- c(-2, -4, 6, 7, 8)

# Extracting the first element of a
a[1]

# Extracting the first and third element of a
a[c(1,3)]

# Lets add a and b
a + b

# Lets add a and b
2 * a + 5

# Storing 5 values in a vector and assigning to 'a'
a <- c(1, 2, 3, 4, 5)

# Storing 5 values in a vector and assigning to 'b'
b <- c(-2, -4, 6, 7, 6)

# Creating a dataframe from 'a' and 'b' 
mydata <- data.frame(a,b)

# Printing mydata
mydata

# List all the datasets stored in R
data()

# Load the iris dataset in the workspace
data(iris)

# Viewing the structure of the iris dataset
nrow(iris)

# Viewing the first 5 rows of the iris dataset
ncol(iris)

# Display the variable names 
names(iris)

# Viewing the structure of the iris dataset
str(iris)

# View the first 6 rows of the iris dataset
head(iris)

# View the last 6 rows of the iris dataset
tail(iris)

# Extracting the variable a from mydata
iris[,'Sepal.Width']

# Extracting the row (or observation) from mydata
iris[1,]

# Extracting the 3rd row for variable b from mydata
iris[3,'Petal.Length']

# Extracting the variable a from mydata
iris$Sepal.Width

# Creating variable c by adding a and b together
iris$Sepal.Width.Plus.Sepal.Length <- iris$Sepal.Width + iris$Sepal.Length

iris$Sepal.Width.Times.Sepal.Length <- iris$Sepal.Width * iris$Sepal.Length

# Printing the variable aplusb
iris$Sepal.Width.Plus.Sepal.Length

# Checking whether 1 == 2
1 == 2

# Checking whether1 == 1
1 == 1

# Subsetting iris where `Sepal.Width` is less than 3
subset(iris, Sepal.Width > 3)

# And assign it to a new dataframe
BigIris <- subset(iris, Sepal.Width > 3)

##########################################################
### Example: HIA associated with outdoor air pollution ###
##########################################################
# Relative Risk
RR <- 1.06

# Size of population
Population <- 1000000

# Unit for the Relative Risk
RR_unit <- 10

# Mortality rate
OMR = 80/10000

# Baseline value of PM2.5 for which there is no increased risk
baseline <- 5

# PM2.5 categories
PM2.5.cats <- c(5,15,25,35,45,55,65,75,85,95,105)

# Create a dataframe containing the PM2.5 categoriess
Impacts <- data.frame(PM2.5.cats)

# Calculating Relative Risks 
Impacts$RR <- RR^((Impacts$PM2.5.cats - baseline)/RR_unit)

# Calculating the rates in each category
Impacts$Rate <- Impacts$RR * OMR

# Add the nuimber of (expected) deaths  per year for each category
Impacts$Deaths.Per.Year <- Impacts$Rate * Population

# The number of deaths
Impacts$Deaths.Per.Year[1]

# We can then calculate the excess numbers of deaths for each category
Impacts$Extra.Deaths <- Impacts$Deaths.Per.Year - Impacts$Deaths.Per.Year[1]

# Calculate the number of deaths gained
diff(Impacts$Extra.Deaths)

# We can now add these gains to the main Impacts dataframe
Impacts$Gain <- c(0,diff(Impacts$Extra.Deaths))

# Plot the Gain against the level of PM2.5 
plot(Impacts$PM2.5.cats, Impacts$Gain,
     xlab = 'PM2.5', # x-axis label
     ylab = 'Gain', # y-axis label
     col = 'green', # border point colour
     pch = 21, # Point type
     bg = 'pink') # center dot colour

# Installing and loading ggplot2 package
install.packages('ggplot2')
library(ggplot2)

# Create a ggplot version of the same plot
ggplot(Impacts, aes(x = PM2.5.cats, y = Gain)) + # Data call
  geom_point(colour = 'green') + # Presenting the data as green points
  geom_line(colour = 'pink') + # Presenting the data as pink lines
  theme_bw() + # Black and white theme
  labs(x = 'PM2.5',
       y = 'Gain',
       title = 'My first health impacts analysis')
  

# Show the results
Impacts


